@@ -7,9 +7,10 @@ class TestDurableChannel:
     self.redis_options = {"redis": {"host": "127.0.0.1", "port": 6379}}
     self.dispatcher = None
     self.worker = None
+    self.calledbackMessage = None
 
   def __timeout_callback(self, message):
-    assert message["content"] == "task"
+    self.calledbackMessage = message
     self.worker.end()
     self.dispatcher.end()
 
@@ -46,4 +47,7 @@ class TestDurableChannel:
     assert message["content"] == "task"
     
     # wait for timeout
-    time.sleep(2)
\ No newline at end of file
+    time.sleep(2)
+
+    # assert to check message timed out 
+    assert self.calledbackMessage["content"] == "task"
\ No newline at end of file
